﻿-- ------------------------------------------------------------
-- ------------------------------------------------------------
-- KNOWLEDGE CENTER TABLE, INDEX, AND VIEW CREATION TEMPLATE
-- ------------------------------------------------------------
-- This script is a template for creating the tablespaces, tables, 
-- indexes, views, and constraints required for the 'KNOWLEDGE CENTER' AML 
-- schema.
-- 
-- 
-- This script is only a template.  It must be customized
-- to the physical environment and volume of data expected. 
-- 
-- This script must be run as an account with DBA privileges.
-- 
-- This script assumes that the default storage engine has been
-- set to the desired storage engine. SAS recommends the InnoDB
-- engine.
-- ------------------------------------------------------------
-- ------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

-- ----------------------------------
-- Create AMLCTR tables and views
-- ----------------------------------

USE `AMLCTR`;

CREATE TABLE AMLCTR.FSK_ACCOUNT_EVENT_ALERT
(
	alert_id              BIGINT NOT NULL,
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	account_key           BIGINT NOT NULL,
	date_key              INTEGER NOT NULL,
	transaction_type_key  BIGINT NOT NULL,
	time_key              INTEGER NOT NULL,
	country_key              INTEGER NOT NULL,
	branch_key            BIGINT NOT NULL,
	transaction_status_key              INTEGER NOT NULL,
	trigger_ind           CHAR(1) NULL,
	 PRIMARY KEY (alert_id,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	alert_id,
	transaction_key,
	segment_id
)
;



CREATE INDEX XIE1FSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	account_key
)
;



CREATE INDEX XIE2FSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	transaction_key
)
;



CREATE INDEX XIE3FSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	transaction_type_key
)
;



CREATE INDEX XIE4FSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	branch_key
)
;



CREATE INDEX XIE5FSK_ACCOUNT_EVENT_ALERT ON FSK_ACCOUNT_EVENT_ALERT
(
	date_key
)
;


CREATE TABLE AMLCTR.FSK_ACCOUNT_PROFILE_ALERT
(
	alert_id              BIGINT NOT NULL,
	month_key             INTEGER NOT NULL,
	account_number        VARCHAR(50) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	transactions_count    NUMERIC(9) NULL,
	deposits_count        NUMERIC(9) NULL,
	withdrawals_count     NUMERIC(9) NULL,
	wires_count           NUMERIC(9) NULL,
	cash_transactions_count  NUMERIC(9) NULL,
	account_value_amount  NUMERIC(18,5) NULL,
	total_transactions_amount  NUMERIC(18,5) NULL,
	total_credits_amount  NUMERIC(18,5) NULL,
	total_debits_amount   NUMERIC(18,5) NULL,
	total_cash_debits_amount  NUMERIC(18,5) NULL,
	total_cash_credits_amount  NUMERIC(18,5) NULL,
	total_wire_credits_amount  NUMERIC(18,5) NULL,
	total_wire_debits_amount  NUMERIC(18,5) NULL,
	beginning_balance_amount  NUMERIC(18,5) NULL,
	average_daily_balance_amount  NUMERIC(18,5) NULL,
	ending_cash_balance_amount  NUMERIC(18,5) NULL,
	max_account_value_amount  NUMERIC(18,5) NULL,
	min_account_value_amount  NUMERIC(18,5) NULL,
	avg_account_value_amount  NUMERIC(18,5) NULL,
	cust_initiated_trans_count  NUMERIC(9) NULL,
	largest_credit_amount  NUMERIC(18,5) NULL,
	largest_debit_amount  NUMERIC(18,5) NULL,
	 PRIMARY KEY (alert_id,month_key,account_number,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ACCOUNT_PROFILE_ALERT ON FSK_ACCOUNT_PROFILE_ALERT
(
	alert_id,
	month_key,
	account_number,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ACCOUNT_TRADE_ALERT
(
	alert_id              BIGINT NOT NULL,
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	account_key           BIGINT NOT NULL,
	branch_key            BIGINT NULL,
	transaction_type_key  BIGINT NULL,
	transaction_status_key	INTEGER NULL,
	trade_date_key        INTEGER NULL,
	associate_key         BIGINT NULL,
	execution_time_key    INTEGER NULL,
	posted_date_key       INTEGER NOT NULL,
	settlement_date_key   INTEGER NOT NULL,
	quantity_executed     NUMERIC(15,5) NULL,
	execution_price       NUMERIC(10,5) NULL,
	transaction_currency_key              INTEGER NULL,
	principal_amount_in_txn_ccy  NUMERIC(15,5) NULL,
	principal_amount      NUMERIC(15,5) NULL,
	principal_amount_in_acct_ccy  NUMERIC(15,5) NOT NULL,
	trigger_ind           CHAR(1) NULL,
	 PRIMARY KEY (alert_id,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ACCOUNT_TRADE_ALERT ON FSK_ACCOUNT_TRADE_ALERT
(
	alert_id,
	transaction_key,
	segment_id
)
;



CREATE INDEX XIE1FSK_ACCOUNT_TRADE_ALERT ON FSK_ACCOUNT_TRADE_ALERT
(
	account_key
)
;



CREATE INDEX XIE2FSK_ACCOUNT_TRADE_ALERT ON FSK_ACCOUNT_TRADE_ALERT
(
	transaction_key,
	transaction_type_key
)
;



CREATE INDEX XIE3FSK_ACCOUNT_TRADE_ALERT ON FSK_ACCOUNT_TRADE_ALERT
(
	associate_key
)
;


CREATE TABLE AMLCTR.FSK_ALERT
(
	alert_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	product_type          CHAR(3) NOT NULL,
	alert_status_code     CHAR(3) NOT NULL,
	money_laundering_risk_score  NUMERIC(3) NOT NULL,
	terror_financing_risk_score  NUMERIC(3) NULL,
	alert_description     VARCHAR(100) NOT NULL,
	alert_suppressed_ind  CHAR(1) NULL,
	primary_entity_level_code  CHAR(3) NOT NULL,
	primary_entity_number  VARCHAR(50) NOT NULL,
	primary_entity_key    BIGINT NULL,
	primary_entity_name   VARCHAR(35) NULL,
	scenario_id           BIGINT NULL,
	scenario_name         VARCHAR(35) NULL,
	suppression_end_date  DATETIME NULL,
	actual_values_text    VARCHAR(255) NULL,
	user_id               BIGINT NOT NULL,
	group_id              BIGINT NOT NULL,
	run_date              DATETIME NOT NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	opened_ind            CHAR(1) NOT NULL,
	employee_ind          CHAR(1) NULL,
	version_number        INTEGER NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (alert_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT ON FSK_ALERT
(
	alert_id,
	segment_id
)
;



CREATE INDEX XIE5FSK_ALERT ON FSK_ALERT
(
	primary_entity_key
)
;



CREATE INDEX XIE6FSK_ALERT ON FSK_ALERT
(
	primary_entity_name
)
;



CREATE INDEX XIE7FSK_ALERT ON FSK_ALERT
(
	user_id
)
;



CREATE INDEX XIE8FSK_ALERT ON FSK_ALERT
(
	group_id
)
;



CREATE INDEX XIE9FSK_ALERT ON FSK_ALERT
(
	primary_entity_number
)
;



CREATE INDEX IDX_ALERT_SCENARIO ON FSK_ALERT
(
	scenario_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_COMMENT
(
	comment_id            BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	alert_id              BIGINT NOT NULL,
	alert_comment_text    VARCHAR(2000) NOT NULL,
	item_id               BIGINT NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (comment_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT_COMMENT ON FSK_ALERT_COMMENT
(
	comment_id,
	segment_id
)
;



CREATE INDEX IDX_ALERT_COMMENT_ALERT ON FSK_ALERT_COMMENT
(
	alert_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_DOCUMENT
(
	document_id           BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	alert_id              BIGINT NOT NULL,
	document_name         VARCHAR(255) NOT NULL,
	document_mime_type_desc  VARCHAR(255) NOT NULL,
	document_location_desc  VARCHAR(2000) NOT NULL,
	document_file_name    VARCHAR(255) NOT NULL,
	document_desc         VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (document_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT_DOCUMENT ON FSK_ALERT_DOCUMENT
(
	document_id,
	segment_id
)
;



CREATE INDEX IDX_ALERT_DOCUMENT_ALERT ON FSK_ALERT_DOCUMENT
(
	alert_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_EMAIL
(
	email_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	alert_id              BIGINT NOT NULL,
	email_to_text         VARCHAR(2000) NOT NULL,
	email_cc_text         VARCHAR(2000) NULL,
	email_subject_desc    VARCHAR(255) NULL,
	email_message_text    VARCHAR(4000) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	 PRIMARY KEY (email_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT_EMAIL ON FSK_ALERT_EMAIL
(
	email_id,
	segment_id
)
;



CREATE INDEX IDX_ALERT_EMAIL_ALERT ON FSK_ALERT_EMAIL
(
	alert_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_ENTITY
(
	alert_id              BIGINT NOT NULL,
	entity_key            BIGINT NOT NULL,
	entity_level_code     CHAR(3) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	entity_number         VARCHAR(50) NOT NULL,
	entity_name           VARCHAR(35) NULL,
	 PRIMARY KEY (alert_id,entity_key,entity_level_code,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT_ENTITY ON FSK_ALERT_ENTITY
(
	alert_id,
	entity_key,
	entity_level_code,
	segment_id
)
;



CREATE INDEX XIE1FSK_ALERT_ENTITY ON FSK_ALERT_ENTITY
(
	entity_number
)
;



CREATE INDEX XIE2FSK_ALERT_ENTITY ON FSK_ALERT_ENTITY
(
	entity_key
)
;



CREATE INDEX IDX_ALERT_ENTITY_ALERT ON FSK_ALERT_ENTITY
(
	alert_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_EVENT
(
	event_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	alert_id              BIGINT NOT NULL,
	event_type_code       CHAR(3) NOT NULL,
	event_description     VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	 PRIMARY KEY (event_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_ALERT_EVENT ON FSK_ALERT_EVENT
(
	event_id,
	segment_id
)
;



CREATE INDEX IDX_ALERT_EVENT_ALERT ON FSK_ALERT_EVENT
(
	alert_id,
	segment_id
)
;


CREATE TABLE AMLCTR.FSK_ALERT_REMINDER
(
	alert_id              BIGINT NOT NULL,
	user_id               BIGINT NOT NULL,
	reminder_date         DATETIME NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	reminder_sent_ind     CHAR(1) NULL,
	 PRIMARY KEY (alert_id,user_id,reminder_date,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ALERT_REMINDER ON FSK_ALERT_REMINDER
(
	alert_id,
	user_id,
	reminder_date,
	segment_id
)
;



CREATE INDEX XIF1FSK_ALERT_REMINDER ON FSK_ALERT_REMINDER
(
	alert_id,
	segment_id
)
;



CREATE INDEX XIF2FSK_ALERT_REMINDER ON FSK_ALERT_REMINDER
(
	user_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ALERT_RISK_FACTOR
(
	alert_id              BIGINT NOT NULL,
	scenario_id           BIGINT NOT NULL,
	entity_number         VARCHAR(50) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	entity_level_code     CHAR(3) NOT NULL,
	actual_values_text    VARCHAR(255) NULL,
	 PRIMARY KEY (alert_id,scenario_id,entity_number,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ALERT_RISK_FACTOR ON FSK_ALERT_RISK_FACTOR
(
	alert_id,
	scenario_id,
	entity_number,
	segment_id
)
;



CREATE INDEX XIE2FSK_ALERT_RISK_FACTOR ON FSK_ALERT_RISK_FACTOR
(
	entity_number
)
;



CREATE INDEX XIF1FSK_ALERT_RISK_FACTOR ON FSK_ALERT_RISK_FACTOR
(
	alert_id,
	segment_id
)
;



CREATE INDEX XIF2FSK_ALERT_RISK_FACTOR ON FSK_ALERT_RISK_FACTOR
(
	scenario_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ASSESSMENT_ROUTING_RULE
(
	routing_rule_id       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	list_id               BIGINT NULL,
	risk_assessment_column_name  VARCHAR(30) NOT NULL,
	route_priority_number  NUMERIC(3) NULL,
	route_type_code       NUMERIC(1) NULL,
	initial_route_id      BIGINT NULL,
	 PRIMARY KEY (routing_rule_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ASSESSMENT_ROUTING_RULE ON FSK_ASSESSMENT_ROUTING_RULE
(
	routing_rule_id,
	segment_id
)
;



CREATE INDEX XIF1FSK_ASSESSMENT_ROUTING_RULE ON FSK_ASSESSMENT_ROUTING_RULE
(
	list_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ASSESSMENT_SEQUENCE
(
	next_sequence_id      BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR'
)
;



CREATE TABLE AMLCTR.FSK_CASH_FLOW_ALERT
(
	alert_id              BIGINT NOT NULL,
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	account_key           BIGINT NOT NULL,
	date_key              INTEGER NOT NULL,
	time_key              INTEGER NOT NULL,
	transaction_type_key  BIGINT NOT NULL,
	country_key              INTEGER NOT NULL,
	transaction_status_key              INTEGER NOT NULL,
	remitter_ext_party_key  BIGINT NULL,
	beneficiary_ext_party_key  BIGINT NOT NULL,
	transaction_currency_key              INTEGER NOT NULL,
	branch_key            BIGINT NOT NULL,
	posted_date_key              INTEGER NULL,
	associate_key         BIGINT NULL,
	executing_party_key   BIGINT NULL,
	currency_amount       NUMERIC(15,5) NULL,
	currency_amount_in_txn_ccy  NUMERIC(15,5) NULL,
	currency_amount_in_account_ccy  NUMERIC(15,5) NULL,
	secondary_account_key  BIGINT NOT NULL,
	related_ind           CHAR(1) NOT NULL DEFAULT 'N',
	trigger_ind           CHAR(1) NULL,
	third_party_ind       CHAR(1) NULL,
	 PRIMARY KEY (alert_id,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	alert_id,
	transaction_key,
	segment_id
)
;



CREATE INDEX XIE1FSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	account_key
)
;



CREATE INDEX XIE2FSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	transaction_key,
	transaction_type_key
)
;



CREATE INDEX XIE3FSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	associate_key
)
;



CREATE INDEX XIE4FSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	executing_party_key
)
;



CREATE INDEX XIE5FSK_CASH_FLOW_ALERT ON FSK_CASH_FLOW_ALERT
(
	date_key
)
;



CREATE TABLE AMLCTR.FSK_CASH_FLOW_BANK_ALERT
(
	alert_id              BIGINT NOT NULL,
	bank_key              BIGINT NOT NULL,
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	role_desc             VARCHAR(20) NULL,
	sequence_number       NUMERIC(2) NULL,
	 PRIMARY KEY (alert_id,bank_key,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_CASH_FLOW_BANK_AL ON FSK_CASH_FLOW_BANK_ALERT
(
	alert_id,
	bank_key,
	transaction_key,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ENTITY_COMMENT
(
	comment_id            BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	entity_level_code     CHAR(3) NOT NULL,
	entity_number         VARCHAR(50) NULL,
	comment_text          VARCHAR(2000) NOT NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	lstupdate_user_id     VARCHAR(35) NULL,
	lstupdate_date        DATETIME NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (comment_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ENTITY_COMMENT ON FSK_ENTITY_COMMENT
(
	comment_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ENTITY_DOCUMENT
(
	document_id           BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	entity_level_code     CHAR(3) NOT NULL,
	entity_number         VARCHAR(50) NULL,
	document_name         VARCHAR(255) NOT NULL,
	document_mime_type_desc  VARCHAR(255) NOT NULL,
	document_location_desc  VARCHAR(2000) NOT NULL,
	document_file_name    VARCHAR(255) NOT NULL,
	document_desc         VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	lstupdate_user_id     VARCHAR(35) NULL,
	lstupdate_date        DATETIME NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (document_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ENTITY_DOCUMENT ON FSK_ENTITY_DOCUMENT
(
	document_id,
	segment_id
)
;



CREATE INDEX XIE1FSK_ENTITY_DOCUMENT ON FSK_ENTITY_DOCUMENT
(
	entity_level_code,
	entity_number,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_GROUP
(
	group_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	group_name            VARCHAR(35) NOT NULL,
	group_desc            VARCHAR(35) NOT NULL,
	version_number        INTEGER NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (group_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_GROUP ON FSK_GROUP
(
	group_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_GROUP_USER
(
	group_id              BIGINT NOT NULL,
	user_id               BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	 PRIMARY KEY (group_id,user_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_GROUP_USER ON FSK_GROUP_USER
(
	group_id,
	user_id,
	segment_id
)
;



CREATE INDEX IDX_GROUP_USER_GROUP ON FSK_GROUP_USER
(
	group_id,
	segment_id
)
;



CREATE INDEX IDX_GROUP_USER_USER ON FSK_GROUP_USER
(
	user_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_HEADER
(
	header_id             BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	header_name           VARCHAR(32) NOT NULL,
	header_description    VARCHAR(255) NOT NULL,
	entity_level_code     CHAR(3) NOT NULL,
	denorm_table_name     VARCHAR(255) NULL,
	alert_table_name      VARCHAR(50) NOT NULL,
	header_autogen_ind    CHAR(1) NOT NULL,
	header_location_desc  VARCHAR(255) NULL,
	source_type_desc      VARCHAR(15) NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	create_date           DATETIME NOT NULL,
	lstupdate_user_id     VARCHAR(35) NULL,
	lstupdate_date        DATETIME NULL,
	header_host_desc      VARCHAR(50) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (header_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_HEADER ON FSK_HEADER
(
	header_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_HEADER_ELEMENT
(
	header_id             BIGINT NOT NULL,
	element_name          VARCHAR(35) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	element_type_code     CHAR(6) NOT NULL,
	element_length_count  INTEGER NULL,
	element_format_code   CHAR(8) NOT NULL,
	element_label_desc    VARCHAR(35) NOT NULL,
	element_usage_desc    VARCHAR(35) NULL,
	 PRIMARY KEY (header_id,element_name,segment_id)
)
;



CREATE UNIQUE INDEX PK_HEADER_ELEMENT ON FSK_HEADER_ELEMENT
(
	header_id,
	element_name,
	segment_id
)
;



CREATE INDEX IDX_HEADER_ELEMENT_HEADER ON FSK_HEADER_ELEMENT
(
	header_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_JOB_CALENDAR
(
	job_calendar_id       INTEGER NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	calendar_date         DATETIME NULL,
	rundate_ind           CHAR(1) NULL,
	daily_rundate_ind     CHAR(1) NOT NULL,
	weekly_rundate_ind    CHAR(1) NOT NULL,
	monthly_rundate_ind   CHAR(1) NOT NULL,
	status_ind            CHAR(1) NOT NULL,
	business_day_count    NUMERIC(15) NULL,
	 PRIMARY KEY (job_calendar_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_JOB_CALENDAR ON FSK_JOB_CALENDAR
(
	job_calendar_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_LIST
(
	list_id               BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	list_category_id      BIGINT NULL,
	list_name             VARCHAR(35) NULL,
	list_desc             VARCHAR(255) NULL,
	validation_type_code  VARCHAR(4) NOT NULL,
	create_date           DATETIME NULL,
	create_user_id        VARCHAR(35) NULL,
	delete_date           DATETIME NULL,
	delete_user_id        VARCHAR(35) NULL,
	logical_delete_ind    CHAR(1) NULL,
	 PRIMARY KEY (list_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_LIST ON FSK_LIST
(
	list_id,
	segment_id
)
;



CREATE INDEX XIF1FSK_LIST ON FSK_LIST
(
	list_category_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_LIST_CATEGORY
(
	list_category_id      BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	list_category_name    VARCHAR(35) NOT NULL,
	list_category_desc    VARCHAR(255) NULL,
	create_date           DATETIME NULL,
	create_user_id        VARCHAR(35) NULL,
	delete_date           DATETIME NULL,
	delete_user_id        VARCHAR(35) NULL,
	logical_delete_ind    CHAR(1) NULL,
	 PRIMARY KEY (list_category_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_LIST_CATEGORY ON FSK_LIST_CATEGORY
(
	list_category_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_LIST_ELEMENT
(
	list_element_id       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	list_id               BIGINT NULL,
	list_element_desc     VARCHAR(35) NULL,
	list_element_value    VARCHAR(75) NOT NULL,
	create_date           DATETIME NULL,
	create_user_id        VARCHAR(35) NULL,
	delete_date           DATETIME NULL,
	delete_user_id        VARCHAR(35) NULL,
	logical_delete_ind    CHAR(1) NULL,
	 PRIMARY KEY (list_element_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_LIST_ELEMENT ON FSK_LIST_ELEMENT
(
	list_element_id,
	segment_id
)
;



CREATE INDEX XIE1FSK_LIST_ELEMENT ON FSK_LIST_ELEMENT
(
	list_element_value
)
;



CREATE INDEX XIF1FSK_LIST_ELEMENT ON FSK_LIST_ELEMENT
(
	list_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_LOV
(
	lov_type_name         CHAR(18) NOT NULL,
	lov_type_code         CHAR(3) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	lov_type_desc         VARCHAR(35) NOT NULL,
	lov_sort_position_number  INTEGER NULL,
	lov_language_desc     VARCHAR(20) NULL,
	 PRIMARY KEY (lov_type_name,lov_type_code,segment_id)
)
;



CREATE UNIQUE INDEX PK_LOV ON FSK_LOV
(
	lov_type_name,
	lov_type_code,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_NETWORK_EXCLUSION
(
	network_exclusion_id  BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	remitter_account_number  VARCHAR(50) NOT NULL,
	beneficiary_account_number  VARCHAR(50) NOT NULL,
	instruction_code      CHAR(1) NULL,
	exclusion_desc        VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	lstupdate_user_id     VARCHAR(35) NULL,
	lstupdate_date        DATETIME NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (network_exclusion_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_NETWORK_EXCLUSION ON FSK_NETWORK_EXCLUSION
(
	network_exclusion_id,
	segment_id
)
;



CREATE INDEX XIE1FSK_NETWORK_EXCLUSION ON FSK_NETWORK_EXCLUSION
(
	remitter_account_number
)
;



CREATE INDEX XIEFSK_NETWORK_EXCLUSION ON FSK_NETWORK_EXCLUSION
(
	beneficiary_account_number
)
;


CREATE TABLE AMLCTR.FSK_PARTY_PROFILE_ALERT
(
	alert_id              BIGINT NOT NULL,
	month_key             INTEGER NOT NULL,
	party_number          VARCHAR(50) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	aggregate_assets_amount  NUMERIC(18,5) NULL,
	transactions_count    NUMERIC(9) NULL,
	deposits_count        NUMERIC(9) NULL,
	withdrawals_count     NUMERIC(9) NULL,
	wires_count           NUMERIC(9) NULL,
	cash_transactions_count  NUMERIC(9) NULL,
	account_value_amount  NUMERIC(9) NULL,
	total_transactions_amount  NUMERIC(18,5) NULL,
	total_credits_amount  NUMERIC(9) NULL,
	total_debits_amount   NUMERIC(18,5) NULL,
	total_cash_debits_amount  NUMERIC(18,5) NULL,
	total_cash_credits_amount  NUMERIC(18,5) NULL,
	total_wire_credits_amount  NUMERIC(18,5) NULL,
	total_wire_debits_amount  NUMERIC(18,5) NULL,
	largest_credit_amount  NUMERIC(18,5) NULL,
	largest_debit_amount  NUMERIC(18,5) NULL,
	funds_payment_svcs_count  NUMERIC(9) NULL,
	funds_transfer_count  NUMERIC(9) NULL,
	monetary_instrument_count  NUMERIC(9) NULL,
	 PRIMARY KEY (alert_id,month_key,party_number,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_PARTY_PROFILE_ALERT ON FSK_PARTY_PROFILE_ALERT
(
	alert_id,
	month_key,
	party_number,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT
(
	risk_assessment_id    BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	risk_assessment_status_code  CHAR(3) NOT NULL,
	risk_classification   NUMERIC(1) NULL,
	proposed_risk_classification  NUMERIC(1) NULL,
	party_number          VARCHAR(50) NOT NULL,
	party_key             BIGINT NULL,
	party_name            VARCHAR(35) NULL,
	user_id               BIGINT NOT NULL,
	group_id              BIGINT NOT NULL,
	starting_month_key              INTEGER NULL,
	risk_assessment_duration  NUMERIC(3) NOT NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	opened_ind            CHAR(1) NOT NULL,
	employee_ind          CHAR(1) NULL,
	version_number        INTEGER NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (risk_assessment_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_RISK_ASS ON FSK_RISK_ASSESSMENT
(
	risk_assessment_id,
	segment_id
)
;



CREATE INDEX XIE5FSK_RISK_ASS ON FSK_RISK_ASSESSMENT
(
	party_key
)
;



CREATE INDEX XIE7FSK_RISK_ASS ON FSK_RISK_ASSESSMENT
(
	user_id
)
;



CREATE INDEX XIE8FSK_RISK_ASS ON FSK_RISK_ASSESSMENT
(
	group_id
)
;



CREATE INDEX XIE9FSK_RISK_ASS ON FSK_RISK_ASSESSMENT
(
	party_number
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_assessment_id    BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	risk_classifier_id    BIGINT NOT NULL,
	 PRIMARY KEY (risk_assessment_id,segment_id,risk_classifier_id)
)
;



CREATE UNIQUE INDEX XPKFSK_RISK_ASSESSMENT_CLASSIFIER ON FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_assessment_id,
	segment_id,
	risk_classifier_id
)
;



CREATE INDEX XIF1FSK_RISK_ASSESSMENT_CLASSIFIER ON FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_assessment_id,
	segment_id
)
;



CREATE INDEX XIF2FSK_RISK_ASSESSMENT_CLASSIFIER ON FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_classifier_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT_COMMENT
(
	comment_id            BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	risk_assessment_id    BIGINT NOT NULL,
	assessment_comment_text  VARCHAR(2000) NOT NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (comment_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_RISK_ASS_COMMENT ON FSK_RISK_ASSESSMENT_COMMENT
(
	comment_id,
	segment_id
)
;



CREATE INDEX IDX_RISK_ASS_COMMENT_ALERT ON FSK_RISK_ASSESSMENT_COMMENT
(
	risk_assessment_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT
(
	document_id           BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	risk_assessment_id    BIGINT NOT NULL,
	document_name         VARCHAR(255) NOT NULL,
	document_mime_type_desc  VARCHAR(255) NOT NULL,
	document_location_desc  VARCHAR(2000) NOT NULL,
	document_file_name    VARCHAR(255) NOT NULL,
	document_desc         VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (document_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_RISK_ASS_DOCUMENT ON FSK_RISK_ASSESSMENT_DOCUMENT
(
	document_id,
	segment_id
)
;



CREATE INDEX IDX_RISK_ASS_DOCUMENT_ALERT ON FSK_RISK_ASSESSMENT_DOCUMENT
(
	risk_assessment_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT_EMAIL
(
	email_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	risk_assessment_id    BIGINT NOT NULL,
	email_to_text         VARCHAR(2000) NOT NULL,
	email_cc_text         VARCHAR(2000) NULL,
	email_subject_desc    VARCHAR(255) NULL,
	email_message_text    VARCHAR(4000) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	 PRIMARY KEY (email_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_RISK_ASS_EMAIL ON FSK_RISK_ASSESSMENT_EMAIL
(
	email_id,
	segment_id
)
;



CREATE INDEX IDX_RISK_ASS_EMAIL_ALERT ON FSK_RISK_ASSESSMENT_EMAIL
(
	risk_assessment_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_ASSESSMENT_EVENT
(
	event_id              BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	risk_assessment_id    BIGINT NOT NULL,
	event_type_code       CHAR(3) NOT NULL,
	event_desc            VARCHAR(255) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	 PRIMARY KEY (event_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_RISK_ASS_EVENT ON FSK_RISK_ASSESSMENT_EVENT
(
	event_id,
	segment_id
)
;



CREATE INDEX IDX_RISK_ASS_EVENT ON FSK_RISK_ASSESSMENT_EVENT
(
	risk_assessment_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_CLASSIFIER
(
	risk_classifier_id    BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	risk_classifier_name  VARCHAR(35) NOT NULL,
	risk_classifier_short_desc  VARCHAR(35) NULL,
	risk_classifier_desc  VARCHAR(255) NULL,
	risk_classifier_type_code  CHAR(3) NULL,
	active_ind            CHAR(1) NULL,
	weight                BIGINT NOT NULL,
	source_table          VARCHAR(35) NULL,
	source_column         VARCHAR(30) NULL,
	source_value          CHAR(1) NULL,
	classifier_fact_column  VARCHAR(30) NULL,
	operator_desc         VARCHAR(3) NULL,
	locked_ind            CHAR(1) NULL,
	classifier_threshold  BIGINT NULL,
	risk_classifier_category_id  BIGINT NULL,
	list_id               BIGINT NULL,
	create_date           DATETIME NULL,
	create_user_id        VARCHAR(35) NULL,
	end_date              DATETIME NULL,
	end_user_id           VARCHAR(35) NULL,
	version_number        NUMERIC(5,0) NULL,
	current_ind           CHAR(1) NOT NULL,
	logical_delete_ind    CHAR(1) NULL,
	 PRIMARY KEY (risk_classifier_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_RISK_CLASSIFIER ON FSK_RISK_CLASSIFIER
(
	risk_classifier_id,
	segment_id
)
;



CREATE INDEX XIF1FSK_RISK_CLASSIFIER ON FSK_RISK_CLASSIFIER
(
	risk_classifier_category_id,
	segment_id
)
;



CREATE INDEX XIF2FSK_RISK_CLASSIFIER ON FSK_RISK_CLASSIFIER
(
	list_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY
(
	risk_classifier_category_id  BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	risk_classifier_category_name  VARCHAR(35) NULL,
	risk_classifier_category_desc  VARCHAR(255) NULL,
	create_date           DATETIME NULL,
	create_user_id        VARCHAR(35) NULL,
	delete_date           DATETIME NULL,
	delete_user_id        VARCHAR(35) NULL,
	logical_delete_ind    CHAR(1) NOT NULL DEFAULT 'N',
	 PRIMARY KEY (risk_classifier_category_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_RISK_CLASSIFIER_CATEGORY ON FSK_RISK_CLASSIFIER_CATEGORY
(
	risk_classifier_category_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ROUTING_CONSTRAINT
(
	routing_group_id      BIGINT NOT NULL,
	routing_rule_id       NUMERIC(3) NOT NULL,
	constraint_sequence_number  NUMERIC(2) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	column_name           VARCHAR(35) NULL,
	operator_desc         CHAR(3) NULL,
	value_desc            VARCHAR(35) NULL,
	compound_operator_name  CHAR(4) NULL,
	 PRIMARY KEY (routing_group_id,routing_rule_id,constraint_sequence_number,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ROUTING_CONSTRAINT ON FSK_ROUTING_CONSTRAINT
(
	routing_group_id,
	routing_rule_id,
	constraint_sequence_number,
	segment_id
)
;



CREATE INDEX XIF1FSK_ROUTING_CONSTRAINT ON FSK_ROUTING_CONSTRAINT
(
	routing_rule_id,
	routing_group_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ROUTING_GROUP
(
	routing_group_id      BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	routing_group_name    VARCHAR(50) NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (routing_group_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ROUTING_GROUP ON FSK_ROUTING_GROUP
(
	routing_group_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_ROUTING_RULE
(
	routing_group_id      BIGINT NOT NULL,
	routing_rule_id       NUMERIC(3) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	route_priority_number  NUMERIC(3) NULL,
	route_type_code       NUMERIC(1) NULL,
	initial_route_id      BIGINT NULL,
	 PRIMARY KEY (routing_group_id,routing_rule_id,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_ROUTING_RULE ON FSK_ROUTING_RULE
(
	routing_group_id,
	routing_rule_id,
	segment_id
)
;



CREATE INDEX XIF1FSK_ROUTING_RULE ON FSK_ROUTING_RULE
(
	routing_group_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_SCENARIO
(
	scenario_id           BIGINT NOT NULL,
	segment_id            VARCHAR(128) NULL DEFAULT 'BANK1KCTR',
	header_id             BIGINT NOT NULL,
	scenario_name         VARCHAR(35) NOT NULL,
	scenario_short_description  VARCHAR(100) NOT NULL,
	scenario_description  VARCHAR(255) NOT NULL,
	scenario_category_code  CHAR(3) NOT NULL,
	scenario_code_location_desc  VARCHAR(255) NOT NULL,
	product_type_code     CHAR(3) NOT NULL,
	scenario_status_code  CHAR(3) NOT NULL,
	scenario_run_frequency_desc  VARCHAR(25) NOT NULL,
	current_ind           CHAR(1) NOT NULL,
	initial_route_id      BIGINT NOT NULL,
	route_type_code       NUMERIC(1) NOT NULL,
	dflt_suppress_duration_count  INTEGER NOT NULL,
	scenario_duration_count  INTEGER NOT NULL,
	money_laundering_bayes_weight  NUMERIC(15,5) NOT NULL,
	terror_financing_bayes_weight  NUMERIC(15,5) NULL,
	execution_probability_rate  NUMERIC(7,7) NOT NULL,
	risk_factor_ind       CHAR(1) NULL,
	create_date           DATETIME NOT NULL,
	create_user_id        VARCHAR(35) NOT NULL,
	end_date              DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	end_user_id           VARCHAR(35) NULL,
	version_number        INTEGER NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	routing_group_id      BIGINT NULL,
	 PRIMARY KEY (scenario_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_SCENARIO ON FSK_SCENARIO
(
	scenario_id,
	segment_id
)
;



CREATE INDEX IDX_SCENARIO_HEADER ON FSK_SCENARIO
(
	header_id,
	segment_id
)
;



CREATE INDEX XIF2FSK_SCENARIO ON FSK_SCENARIO
(
	routing_group_id,
	segment_id
)
;



CREATE TABLE AMLCTR.FSK_SCENARIO_PARAMETER
(
	scenario_id           BIGINT NOT NULL,
	parm_name             VARCHAR(35) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	parm_value            VARCHAR(1024) NOT NULL,
	parm_type_desc        VARCHAR(20) NOT NULL,
	parm_desc             VARCHAR(255) NOT NULL,
	 PRIMARY KEY (scenario_id,parm_name,segment_id)
)
;



CREATE UNIQUE INDEX PK_SCENARIO_PARAMETER ON FSK_SCENARIO_PARAMETER
(
	scenario_id,
	parm_name,
	segment_id
)
;



CREATE INDEX IDX_SCENARIO_PARAM_SCENARIO ON FSK_SCENARIO_PARAMETER
(
	scenario_id,
	segment_id
)
;




CREATE TABLE AMLCTR.FSK_TRANSACTION_ALERT
(
	alert_id              BIGINT NOT NULL,
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	date_key              INTEGER NOT NULL,
	transaction_reference_number  VARCHAR(50) NOT NULL,
	transaction_description  VARCHAR(255) NULL,
	security_name         VARCHAR(35) NULL,
	deal_number           VARCHAR(35) NULL,
	 PRIMARY KEY (alert_id,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSK_TRANSACTION_AL ON FSK_TRANSACTION_ALERT
(
	alert_id,
	transaction_key,
	segment_id
)
;



CREATE INDEX XIE1FSK_TRANSACTION_AL ON FSK_TRANSACTION_ALERT
(
	transaction_reference_number
)
;



CREATE INDEX XIE2FSK_TRANSACTION_AL ON FSK_TRANSACTION_ALERT
(
	date_key
)
;



CREATE INDEX XIE3FSK_TRANSACTION_AL ON FSK_TRANSACTION_ALERT
(
	transaction_key
)
;



CREATE TABLE AMLCTR.FSK_UI_AVAILABILITY
(
	ui_availability_ind   CHAR(1) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR'
)
;



CREATE TABLE AMLCTR.FSK_UI_COLUMN
(
	table_ui_name         VARCHAR(35) NOT NULL,
	column_ui_name        VARCHAR(35) NOT NULL,
	group_ui_name         VARCHAR(35) NOT NULL,
	column_expression_text  VARCHAR(255) NULL,
	column_label_desc     VARCHAR(64) NULL,
	column_position_number  INTEGER NULL,
	format_code           CHAR(3) NULL,
	format_modifier_text  VARCHAR(1024) NULL,
	column_display_level_code  CHAR(3) NULL,
	column_search_level_code  CHAR(3) NULL,
	sorted_by_position_number  INTEGER NULL,
	column_active_ind     CHAR(1) NULL,
	local_key_db_name     VARCHAR(35) NULL,
	remote_key_db_name    VARCHAR(35) NULL,
	remote_table_ui_name  VARCHAR(35) NULL,
	 PRIMARY KEY (table_ui_name,column_ui_name)
)
;



CREATE UNIQUE INDEX XPKFSK_UI_COLUMN ON FSK_UI_COLUMN
(
	table_ui_name,
	column_ui_name
)
;



CREATE INDEX XIF1FSK_UI_COLUMN ON FSK_UI_COLUMN
(
	table_ui_name
)
;



CREATE INDEX XIF2FSK_UI_COLUMN ON FSK_UI_COLUMN
(
	group_ui_name
)
;



CREATE TABLE AMLCTR.FSK_UI_GROUP
(
	group_ui_name         VARCHAR(35) NOT NULL,
	group_label_desc      VARCHAR(64) NULL,
	group_position_number  INTEGER NULL,
	 PRIMARY KEY (group_ui_name)
)
;



CREATE UNIQUE INDEX XPKFSK_UI_GROUP ON FSK_UI_GROUP
(
	group_ui_name
)
;



CREATE TABLE AMLCTR.FSK_UI_TABLE
(
	table_ui_name         VARCHAR(35) NOT NULL,
	table_expression_text  VARCHAR(2000) NULL,
	table_label_desc      VARCHAR(64) NULL,
	table_data_source_code  CHAR(3) NULL,
	table_search_level_code  CHAR(3) NULL,
	table_active_ind      CHAR(1) NULL,
	 PRIMARY KEY (table_ui_name)
)
;



CREATE UNIQUE INDEX XPKFSK_UI_TABLE ON FSK_UI_TABLE
(
	table_ui_name
)
;


CREATE TABLE  AMLCTR.FSK_SCD2_COLUMNS (
  scd2_key BIGINT NOT NULL,
  segment_id VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
  table_name VARCHAR(35) NOT NULL,
  column_name VARCHAR(35) NOT NULL,
  xref_valid_ind CHAR(1) NOT NULL,
  create_date datetime NOT NULL,
  end_date datetime NOT NULL,
  create_user_id VARCHAR(35) NOT NULL,
  version_number INTEGER NOT NULL,
  current_ind CHAR(1) NOT NULL,
  PRIMARY KEY  (scd2_key,segment_id)
);


CREATE TABLE AMLCTR.FSK_USER
(
	user_id               BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	user_long_id          VARCHAR(35) NOT NULL,
	display_name          VARCHAR(35) NOT NULL,
	email_address         VARCHAR(255) NOT NULL,
	user_privileges_code  NUMERIC(19) NULL,
	starting_tab_pref     VARCHAR(35) NULL,
	alert_rows_displayed_pref  SMALLINT NULL,
	query_rows_displayed_pref  SMALLINT NULL,
	assessmnt_rows_displayed_pref  SMALLINT NULL,
	trans_rows_displayed_pref  SMALLINT NULL,
	manager_id            BIGINT NULL,
	administrator_ind     CHAR(1) NULL,
	version_number        BIGINT NOT NULL,
	logical_delete_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (user_id,segment_id)
)
;



CREATE UNIQUE INDEX PK_USER ON FSK_USER
(
	user_id,
	segment_id
)
;


CREATE VIEW AMLCTR.FSK_ACCOUNT_LIST_VIEW AS
	SELECT element.list_id,element.list_element_value,list.segment_id
		FROM AMLCTR.FSK_LIST list,AMLCTR.FSK_LIST_ELEMENT element
		WHERE list.list_id = element.list_id
and list.validation_type_code = 'ACC'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
and list.segment_id = element.segment_id
;



CREATE VIEW AMLCTR.FSK_PARTY_LIST_VIEW AS
	SELECT element.list_id,element.list_element_value,list.segment_id
		FROM AMLCTR.FSK_LIST list,AMLCTR.FSK_LIST_ELEMENT element
		WHERE list.list_id = element.list_id
and list.validation_type_code = 'PTY'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
and list.segment_id = element.segment_id
;


-- -------------------------------------------------
-- Create BANK1KCTR tables and views.
-- -------------------------------------------------

USE `BANK1KCTR`;


CREATE TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_HHD
(
	alert_id              BIGINT NOT NULL,
	account_key           BIGINT NOT NULL,
	run_date              DATETIME NULL,
	 PRIMARY KEY (alert_id,account_key)
)
;



CREATE UNIQUE INDEX XPKFSK_ACCOUNT_KEYS_HHD ON FSK_ACCOUNT_KEYS_HHD
(
	alert_id,
	account_key
)
;



CREATE INDEX XIEFSK_ACCOUNT_KEYS_HHD ON FSK_ACCOUNT_KEYS_HHD
(
	account_key
)
;



CREATE TABLE BANK1KCTR.FSK_ACCOUNT_KEYS_PTY
(
	alert_id              BIGINT NOT NULL,
	account_key           BIGINT NOT NULL,
	run_date              DATETIME NULL,
	 PRIMARY KEY (alert_id,account_key)
)
;



CREATE UNIQUE INDEX XPKFSK_ACCOUNT_KEYS_PTY ON FSK_ACCOUNT_KEYS_PTY
(
	alert_id,
	account_key
)
;



CREATE INDEX XIE1FSK_ACCOUNT_KEYS_PTY ON FSK_ACCOUNT_KEYS_PTY
(
	account_key
)
;



CREATE TABLE BANK1KCTR.FSK_ALERT_NEIGHBOR
(
	alert_id              BIGINT NOT NULL,
	target_account_number  VARCHAR(50) NOT NULL,
	neighbor_account_number  VARCHAR(50) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	distance              NUMERIC(4,3) NULL,
	 PRIMARY KEY (alert_id,target_account_number,neighbor_account_number)
)
;



CREATE UNIQUE INDEX XPKFSK_ALERT_NEIGHBOR ON FSK_ALERT_NEIGHBOR
(
	alert_id,
	target_account_number,
	neighbor_account_number
)
;



CREATE INDEX XIE1FSK_ALERT_NEIGHBOR ON FSK_ALERT_NEIGHBOR
(
	target_account_number
)
;



CREATE INDEX XIE2FSK_ALERT_NEIGHBOR ON FSK_ALERT_NEIGHBOR
(
	neighbor_account_number
)
;



CREATE INDEX XIF1FSK_ALERT_NEIGHBOR ON FSK_ALERT_NEIGHBOR
(
	alert_id,
	segment_id
)
;


CREATE TABLE BANK1KCTR.FSK_EDGE_FACT
(
	edge_key              BIGINT NOT NULL,
	network_key           BIGINT NOT NULL,
	edge_type_code        CHAR(1) NOT NULL DEFAULT 'U',
	remitter_account_number  VARCHAR(101) NOT NULL,
	beneficiary_account_number  VARCHAR(101) NOT NULL,
	edge_begin_date       DATETIME NULL,
	edge_transaction_count  BIGINT NULL,
	edge_amount           NUMERIC(15,5) NULL,
	 PRIMARY KEY (edge_key,network_key)
)
;



CREATE UNIQUE INDEX XPKFSK_EDGE_FACT ON FSK_EDGE_FACT
(
	edge_key,
	network_key
)
;



CREATE INDEX XIF1FSK_EDGE_FACT ON FSK_EDGE_FACT
(
	network_key
)
;



CREATE TABLE BANK1KCTR.FSK_NETWORK_DIM
(
	network_key           BIGINT NOT NULL,
	node_count            BIGINT NULL,
	edge_count            BIGINT NULL,
	transaction_count     BIGINT NULL,
	network_amount        NUMERIC(15,5) NULL,
	create_date           DATETIME NULL,
	 PRIMARY KEY (network_key)
)
;



CREATE UNIQUE INDEX XPKFSK_NETWORK_DIM ON FSK_NETWORK_DIM
(
	network_key
)
;



CREATE TABLE BANK1KCTR.FSK_NN_ENTITY
(
	primary_entity_number  VARCHAR(76) NOT NULL,
	primary_entity_level_code  CHAR(3) NOT NULL,
	alert_id              BIGINT NOT NULL,
	 PRIMARY KEY (primary_entity_number,primary_entity_level_code,alert_id)
)
;



CREATE UNIQUE INDEX XPKFSK_NN_ENTITY ON FSK_NN_ENTITY
(
	primary_entity_number,
	primary_entity_level_code,
	alert_id
)
;



CREATE INDEX XIE1FSK_NN_ENTITY ON FSK_NN_ENTITY
(
	alert_id
)
;



CREATE TABLE BANK1KCTR.FSK_NN_PARTY
(
	alert_id              BIGINT NOT NULL,
	party_number          VARCHAR(76) NOT NULL,
	 PRIMARY KEY (alert_id,party_number)
)
;



CREATE UNIQUE INDEX XPKFSK_NN_PARTY ON FSK_NN_PARTY
(
	alert_id,
	party_number
)
;



CREATE INDEX XIE1FSK_NN_PARTY ON FSK_NN_PARTY
(
	party_number
)
;



CREATE TABLE BANK1KCTR.FSK_NODE_FACT
(
	node_key              BIGINT NULL,
	network_key           BIGINT NOT NULL,
	account_number        VARCHAR(101) NULL,
	 PRIMARY KEY (node_key,network_key)
)
;



CREATE UNIQUE INDEX XPKFSK_NODE_FACT ON FSK_NODE_FACT
(
	node_key,
	network_key
)
;



CREATE INDEX XIF1FSK_NODE_FACT ON FSK_NODE_FACT
(
	network_key
)
;




CREATE TABLE BANK1KCTR.FSK_REPLICATION_DATES
(
	alert_id              BIGINT NOT NULL,
	start_date            DATETIME NULL,
	start_date_key        INTEGER NULL,
	 PRIMARY KEY (alert_id)
)
;



CREATE UNIQUE INDEX XPKFSK_REPLICATION_DATES ON FSK_REPLICATION_DATES
(
	alert_id
)
;




CREATE TABLE AMLCTR.FSK_SEQUENCE
(
	next_sequence_id      BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR'
)
;

CREATE TABLE BANK1KCTR.fsk_seq (
   next_sequence_id BIGINT NOT NULL);

insert into BANK1KCTR.FSK_SEQ (next_sequence_id) values (11000);

-- --------------------------------------------
-- User Defined Function to simulate a sequence
-- Note you will need to have the super 
-- privledge to execute this code

DROP FUNCTION IF EXISTS BANK1KCTR.GET_SEQ;

DELIMITER //

CREATE DEFINER=`BANK1KCTR`@`%` FUNCTION `BANK1KCTR`.`GET_SEQ`() RETURNS BIGINT UNSIGNED
BEGIN
#
 UPDATE fsk_seq SET next_sequence_id=last_insert_id(next_sequence_id+1);
#
 RETURN last_insert_id();
#
END //

DELIMITER ;



CREATE TABLE BANK1KCTR.FSK_TEMP_NUMBER
(
	primary_entity_number  VARCHAR(50) NOT NULL,
	 PRIMARY KEY (primary_entity_number)
)
;



CREATE UNIQUE INDEX XPKFSK_TEMP_NUMBER ON FSK_TEMP_NUMBER
(
	primary_entity_number
)
;


-- -----------------------------------
-- Create foreign key constraints
-- -----------------------------------

USE `AMLCTR`;

ALTER TABLE AMLCTR.FSK_ALERT
	ADD FOREIGN KEY FK_ALERT_SCENARIO (scenario_id,segment_id) REFERENCES AMLCTR.FSK_SCENARIO(scenario_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ALERT_COMMENT
	ADD FOREIGN KEY FK_ALERT_COMMENT_ALERT (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ALERT_DOCUMENT
	ADD FOREIGN KEY FK_ALERT_DOCUMENT_ALERT (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ALERT_EMAIL
	ADD FOREIGN KEY FK_ALERT_EMAIL_ALERT (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ALERT_ENTITY
	ADD FOREIGN KEY FK_ALERT_ENTITY_ALERT (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ALERT_EVENT
	ADD FOREIGN KEY FK_ALERT_EVENT_ALERT (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ALERT_REMINDER
	ADD FOREIGN KEY R_67 (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ALERT_REMINDER
	ADD FOREIGN KEY R_68 (user_id,segment_id) REFERENCES AMLCTR.FSK_USER(user_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ALERT_RISK_FACTOR
	ADD FOREIGN KEY R_51 (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ALERT_RISK_FACTOR
	ADD FOREIGN KEY R_52 (scenario_id,segment_id) REFERENCES AMLCTR.FSK_SCENARIO(scenario_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_ASSESSMENT_ROUTING_RULE
	ADD FOREIGN KEY R_100 (list_id,segment_id) REFERENCES AMLCTR.FSK_LIST(list_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_GROUP_USER
	ADD FOREIGN KEY FK_GROUP_USER_GROUP (group_id,segment_id) REFERENCES AMLCTR.FSK_GROUP(group_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_GROUP_USER
	ADD FOREIGN KEY FK_GROUP_USER_USER (user_id,segment_id) REFERENCES AMLCTR.FSK_USER(user_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_HEADER_ELEMENT
	ADD FOREIGN KEY FK_HEADER_ELEMENT_HEADER (header_id,segment_id) REFERENCES AMLCTR.FSK_HEADER(header_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_LIST
	ADD FOREIGN KEY R_72 (list_category_id,segment_id) REFERENCES AMLCTR.FSK_LIST_CATEGORY(list_category_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_LIST_ELEMENT
	ADD FOREIGN KEY R_73 (list_id,segment_id) REFERENCES AMLCTR.FSK_LIST(list_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER
	ADD FOREIGN KEY R_95 (risk_assessment_id,segment_id) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT(risk_assessment_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER
	ADD FOREIGN KEY R_97 (risk_classifier_id,segment_id) REFERENCES AMLCTR.FSK_RISK_CLASSIFIER(risk_classifier_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_COMMENT
	ADD FOREIGN KEY FK_RISK_ASS_COMMENT_ALERT (risk_assessment_id,segment_id) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT(risk_assessment_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT
	ADD FOREIGN KEY FK_RISK_ASS_DOCUMENT_ALERT (risk_assessment_id,segment_id) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT(risk_assessment_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_EMAIL
	ADD FOREIGN KEY FK_RISK_ASS_EMAIL_ALERT (risk_assessment_id,segment_id) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT(risk_assessment_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_RISK_ASSESSMENT_EVENT
	ADD FOREIGN KEY FK_RISK_ASS_EVENT_ALERT (risk_assessment_id,segment_id) REFERENCES AMLCTR.FSK_RISK_ASSESSMENT(risk_assessment_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_RISK_CLASSIFIER
	ADD FOREIGN KEY R_79 (risk_classifier_category_id,segment_id) REFERENCES AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY(risk_classifier_category_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_RISK_CLASSIFIER
	ADD FOREIGN KEY R_80 (list_id,segment_id) REFERENCES AMLCTR.FSK_LIST(list_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ROUTING_CONSTRAINT
	ADD FOREIGN KEY R_55 (routing_group_id,routing_rule_id,segment_id) REFERENCES AMLCTR.FSK_ROUTING_RULE(routing_group_id,routing_rule_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_ROUTING_RULE
	ADD FOREIGN KEY R_64 (routing_group_id,segment_id) REFERENCES AMLCTR.FSK_ROUTING_GROUP(routing_group_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_SCENARIO
	ADD FOREIGN KEY FK_SCENARIO_HEADER (header_id,segment_id) REFERENCES AMLCTR.FSK_HEADER(header_id,segment_id)
;


ALTER TABLE AMLCTR.FSK_SCENARIO
	ADD FOREIGN KEY R_66 (routing_group_id,segment_id) REFERENCES AMLCTR.FSK_ROUTING_GROUP(routing_group_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_SCENARIO_PARAMETER
	ADD FOREIGN KEY FK_SCENARIO_PARAMETER_SCENARIO (scenario_id,segment_id) REFERENCES AMLCTR.FSK_SCENARIO(scenario_id,segment_id)
;



ALTER TABLE AMLCTR.FSK_UI_COLUMN
	ADD FOREIGN KEY R_49 (table_ui_name) REFERENCES AMLCTR.FSK_UI_TABLE(table_ui_name)
;


ALTER TABLE AMLCTR.FSK_UI_COLUMN
	ADD FOREIGN KEY R_50 (group_ui_name) REFERENCES AMLCTR.FSK_UI_GROUP(group_ui_name)
;


USE `BANK1KCTR`;

ALTER TABLE BANK1KCTR.FSK_ALERT_NEIGHBOR
	ADD FOREIGN KEY R_56 (alert_id,segment_id) REFERENCES AMLCTR.FSK_ALERT(alert_id,segment_id)
;


ALTER TABLE BANK1KCTR.FSK_EDGE_FACT
	ADD FOREIGN KEY R_173 (network_key) REFERENCES BANK1KCTR.FSK_NETWORK_DIM(network_key)
;



ALTER TABLE BANK1KCTR.FSK_NODE_FACT
	ADD FOREIGN KEY R_174 (network_key) REFERENCES BANK1KCTR.FSK_NETWORK_DIM(network_key)
;


SET FOREIGN_KEY_CHECKS = 1;


create view BANK1KCTR.FSK_ACCOUNT_EVENT_ALERT as select * from AMLCTR.FSK_ACCOUNT_EVENT_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ACCOUNT_PROFILE_ALERT as select * from AMLCTR.FSK_ACCOUNT_PROFILE_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ACCOUNT_TRADE_ALERT as select * from AMLCTR.FSK_ACCOUNT_TRADE_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT as select * from AMLCTR.FSK_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_COMMENT as select * from AMLCTR.FSK_ALERT_COMMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_DOCUMENT as select * from AMLCTR.FSK_ALERT_DOCUMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_EMAIL as select * from AMLCTR.FSK_ALERT_EMAIL where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_ENTITY as select * from AMLCTR.FSK_ALERT_ENTITY where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_EVENT as select * from AMLCTR.FSK_ALERT_EVENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_REMINDER as select * from AMLCTR.FSK_ALERT_REMINDER where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ALERT_RISK_FACTOR as select * from AMLCTR.FSK_ALERT_RISK_FACTOR where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ASSESSMENT_SEQUENCE as select * from AMLCTR.FSK_ASSESSMENT_SEQUENCE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_CASH_FLOW_ALERT as select * from AMLCTR.FSK_CASH_FLOW_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_CASH_FLOW_BANK_ALERT as select * from AMLCTR.FSK_CASH_FLOW_BANK_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ENTITY_COMMENT as select * from AMLCTR.FSK_ENTITY_COMMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ENTITY_DOCUMENT as select * from AMLCTR.FSK_ENTITY_DOCUMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_GROUP as select * from AMLCTR.FSK_GROUP where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_GROUP_USER as select * from AMLCTR.FSK_GROUP_USER where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_SCD2_COLUMNS as select * from AMLCTR.FSK_SCD2_COLUMNS where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSK_HEADER as select
   HEADER_ID,
   HEADER_NAME,
   HEADER_DESCRIPTION,
   ENTITY_LEVEL_CODE,
   DENORM_TABLE_NAME,
   ALERT_TABLE_NAME,
   HEADER_AUTOGEN_IND,
   HEADER_LOCATION_DESC,
   SOURCE_TYPE_DESC,
   CREATE_USER_ID,
   CREATE_DATE,
   LSTUPDATE_USER_ID,
   LSTUPDATE_DATE,
   HEADER_HOST_DESC,
   LOGICAL_DELETE_IND
   from AMLCTR.FSK_HEADER where segment_id='BANK1KCTR';

create view BANK1KCTR.FSK_HEADER_ELEMENT as select
   HEADER_ID,
   ELEMENT_NAME,
   ELEMENT_TYPE_CODE,
   ELEMENT_LENGTH_COUNT,
   ELEMENT_FORMAT_CODE,
   ELEMENT_LABEL_DESC,
   ELEMENT_USAGE_DESC
   from AMLCTR.FSK_HEADER_ELEMENT where segment_id='BANK1KCTR';

create view BANK1KCTR.FSK_JOB_CALENDAR as select * from AMLCTR.FSK_JOB_CALENDAR where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_LIST as select * from AMLCTR.FSK_LIST where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_LIST_CATEGORY as select * from AMLCTR.FSK_LIST_CATEGORY where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_LIST_ELEMENT as select * from AMLCTR.FSK_LIST_ELEMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_LOV as select * from AMLCTR.FSK_LOV where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_NETWORK_EXCLUSION as select * from AMLCTR.FSK_NETWORK_EXCLUSION where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_PARTY_PROFILE_ALERT as select * from AMLCTR.FSK_PARTY_PROFILE_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT_CLASSIFIER as select * from AMLCTR.FSK_RISK_ASSESSMENT_CLASSIFIER where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT_COMMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_COMMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT_DOCUMENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_DOCUMENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT_EMAIL as select * from AMLCTR.FSK_RISK_ASSESSMENT_EMAIL where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_ASSESSMENT_EVENT as select * from AMLCTR.FSK_RISK_ASSESSMENT_EVENT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_CLASSIFIER as select * from AMLCTR.FSK_RISK_CLASSIFIER where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_RISK_CLASSIFIER_CATEGORY as select * from AMLCTR.FSK_RISK_CLASSIFIER_CATEGORY where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSK_ROUTING_CONSTRAINT as select 
	routing_group_id,
	routing_rule_id,
	constraint_sequence_number,
	column_name,
	operator_desc,
	value_desc,
	compound_operator_name 
from AMLCTR.FSK_ROUTING_CONSTRAINT where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSK_ROUTING_GROUP as select 
	routing_group_id,
	routing_group_name,
	logical_delete_ind 
from AMLCTR.FSK_ROUTING_GROUP where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSK_ROUTING_RULE as select 
	routing_group_id,
	routing_rule_id,
	route_priority_number,
	route_type_code,
	initial_route_id
from AMLCTR.FSK_ROUTING_RULE where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSK_SCENARIO as select
   SCENARIO_ID,
   HEADER_ID,
   SCENARIO_NAME,
   SCENARIO_SHORT_DESCRIPTION,
   SCENARIO_DESCRIPTION,
   SCENARIO_CATEGORY_CODE,
   SCENARIO_CODE_LOCATION_DESC,
   PRODUCT_TYPE_CODE,
   SCENARIO_STATUS_CODE,
   SCENARIO_RUN_FREQUENCY_DESC,
   CURRENT_IND,
   INITIAL_ROUTE_ID,
   ROUTE_TYPE_CODE,
   DFLT_SUPPRESS_DURATION_COUNT,
   SCENARIO_DURATION_COUNT,
   MONEY_LAUNDERING_BAYES_WEIGHT,
   TERROR_FINANCING_BAYES_WEIGHT,
   EXECUTION_PROBABILITY_RATE,
   RISK_FACTOR_IND,
   CREATE_DATE,
   CREATE_USER_ID,
   END_DATE,
   END_USER_ID,
   VERSION_NUMBER,
   LOGICAL_DELETE_IND,
   ROUTING_GROUP_ID
   from AMLCTR.FSK_SCENARIO where segment_id='BANK1KCTR';

create view BANK1KCTR.FSK_SCENARIO_PARAMETER as select
   SCENARIO_ID ,
   PARM_NAME ,
   PARM_VALUE ,
   PARM_TYPE_DESC,
   PARM_DESC
   from AMLCTR.FSK_SCENARIO_PARAMETER where segment_id='BANK1KCTR';

create view BANK1KCTR.FSK_SEQUENCE as select
   next_sequence_id
   from AMLCTR.FSK_SEQUENCE where segment_id='BANK1KCTR';
   
create view BANK1KCTR.FSK_TRANSACTION_ALERT as select * from AMLCTR.FSK_TRANSACTION_ALERT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_UI_AVAILABILITY as select * from AMLCTR.FSK_UI_AVAILABILITY where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_UI_COLUMN as select * from AMLCTR.FSK_UI_COLUMN;
create view BANK1KCTR.FSK_UI_GROUP as select * from AMLCTR.FSK_UI_GROUP;
create view BANK1KCTR.FSK_UI_TABLE as select * from AMLCTR.FSK_UI_TABLE;
create view BANK1KCTR.FSK_USER as select * from AMLCTR.FSK_USER where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSK_ASSESSMENT_ROUTING_RULE as select * from AMLCTR.FSK_ASSESSMENT_ROUTING_RULE where segment_id = 'BANK1KCTR';



create view BANK1KCTR.fsk_account_list_view (
   list_id,
   value )
AS
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'ACC'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK1KCTR'
AND element.segment_id = 'BANK1KCTR';



create view BANK1KCTR.fsk_party_list_view (
   list_id,
   value )
AS
SELECT element.list_id,element.list_element_value
FROM AMLCTR.FSK_LIST list
JOIN AMLCTR.FSK_LIST_ELEMENT element ON list.list_id = element.list_id
WHERE list.validation_type_code = 'PTY'
AND list.logical_delete_ind = 'N'
AND element.logical_delete_ind = 'N'
AND list.segment_id = 'BANK1KCTR'
AND element.segment_id = 'BANK1KCTR';


create view BANK1KCTR.fsk_customer_transaction_view (
   transaction_reference_number,
   account_number,
   role_desc,
   date_key,
   currency_amount,
   currency_code,
   transaction_cdi_code,
   transaction_cdi_desc,
   primary_medium_desc,
   secondary_medium_desc,
   mechanism_desc,
   country_code,
   secondary_account_number,
   related_ind,
   third_party_ind,
   remitter_name,
   beneficiary_name,
   branch_name,
   associate_name,
   transaction_description,
   status_desc,
   transaction_key,
   account_key,
   secondary_account_key,
   remitter_ext_party_key,
   beneficiary_ext_party_key,
   branch_key,
   associate_key,
   party_number,
   branch_number,
   associate_number )
as
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cff.date_key,
 cff.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cff.related_ind,
 cff.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 cff.secondary_account_key,
 cff.remitter_ext_party_key,
 cff.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_cash_flow_fact cff 
JOIN AMLCORE.fsc_account_dim acct on cff.account_key = acct.account_key and cff.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cff.secondary_account_key = secacct.account_key and cff.segment_id = secacct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON cff.transaction_key=c.transaction_key and cff.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cff.transaction_type_key
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cff.account_key and br.segment_id = cff.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cff.transaction_currency_key 
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cff.country_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cff.branch_key and cff.segment_id = branch.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cff.associate_key and cff.segment_id = ass.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cff.remitter_ext_party_key = rextpty.ext_party_account_key and cff.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cff.beneficiary_ext_party_key = bextpty.ext_party_account_key and cff.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cff.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cff.segment_id = 'BANK1KCTR'
UNION 
SELECT 
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 trd.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 NULL as secondary_account_key,
 NULL as remitter_ext_party_key,
 NULL as beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCORE.fsc_account_trade_fact trd 
JOIN AMLCORE.fsc_account_dim acct on trd.account_key = acct.account_key and trd.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON trd.transaction_key=c.transaction_key and trd.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trd.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trd.account_key and br.segment_id = trd.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trd.associate_key and ass.segment_id = trd.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trd.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trd.branch_key and branch.segment_id = trd.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on stat.transaction_status_key = trd.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trd.segment_id = 'BANK1KCTR'
UNION 
SELECT
 c.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 c.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 c.transaction_description,
 stat.status_desc,
 c.transaction_key,
 acct.account_key,
 NULL as secondary_account_key,
 NULL as remitter_ext_party_key,
 NULL as beneficiary_ext_party_key,
 branch.branch_key,
 NULL as associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 NULL as associate_number
FROM AMLCORE.fsc_account_event_fact evt 
JOIN AMLCORE.fsc_account_dim acct on evt.account_key = acct.account_key and evt.segment_id = acct.segment_id
JOIN AMLCORE.fsc_transaction_dim c ON evt.transaction_key=c.transaction_key and evt.segment_id = c.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evt.account_key and br.segment_id = evt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evt.branch_key and branch.segment_id = evt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evt.segment_id = 'BANK1KCTR'
UNION
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 cfa.date_key,
 cfa.currency_amount,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 cty.country_code_3 as country_code,
 secacct.account_number,
 cfa.related_ind,
 cfa.third_party_ind,
 rextpty.full_name as remitter_name, 
 bextpty.full_name as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 cfa.secondary_account_key,
 cfa.remitter_ext_party_key,
 cfa.beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_cash_flow_alert cfa 
JOIN AMLCORE.fsc_account_dim acct on cfa.account_key = acct.account_key and cfa.segment_id = acct.segment_id
JOIN AMLCORE.fsc_account_dim secacct on cfa.secondary_account_key = secacct.account_key and cfa.segment_id = secacct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON cfa.transaction_key=fta.transaction_key and cfa.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = cfa.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = cfa.account_key and br.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = cfa.transaction_currency_key
JOIN AMLCORE.fsc_country_dim cty on cty.country_key = cfa.country_key 
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = cfa.branch_key and branch.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = cfa.associate_key and ass.segment_id = cfa.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim rextpty on cfa.remitter_ext_party_key = rextpty.ext_party_account_key and cfa.segment_id = rextpty.segment_id
JOIN AMLCORE.fsc_ext_party_account_dim bextpty on cfa.beneficiary_ext_party_key = bextpty.ext_party_account_key and cfa.segment_id = bextpty.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on cfa.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE cfa.segment_id = 'BANK1KCTR'
UNION 
SELECT 
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 trdalrt.principal_amount_in_txn_ccy,
 curr.currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ass.associate_first_name||' '||ass.associate_middle_name||' '||ass.associate_last_name as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 NULL as secondary_account_key,
 NULL as remitter_ext_party_key,
 NULL as beneficiary_ext_party_key,
 branch.branch_key,
 ass.associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 ass.associate_number
FROM AMLCTR.fsk_account_trade_alert trdalrt 
JOIN AMLCORE.fsc_account_dim acct on trdalrt.account_key = acct.account_key and trdalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON trdalrt.transaction_key=fta.transaction_key and trdalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = trdalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = trdalrt.account_key and br.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_associate_dim ass on ass.associate_key = trdalrt.associate_key and ass.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_currency_dim curr on curr.currency_key = trdalrt.transaction_currency_key
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = trdalrt.branch_key and branch.segment_id = trdalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on trdalrt.transaction_status_key = stat.transaction_status_key
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE trdalrt.segment_id = 'BANK1KCTR'
UNION 
SELECT
 fta.transaction_reference_number,
 acct.account_number,
 br.role_desc,
 fta.date_key,
 0 as principal_amount_in_txn_ccy,
 ' ' as currency_code,
 cred_typ.transaction_cdi_code,
 cred_typ.transaction_cdi_desc,
 cred_typ.primary_medium_desc,
 cred_typ.secondary_medium_desc,
 cred_typ.mechanism_desc,
 ' ' as country_code,
 ' ' as account_number,
 ' ' as related_ind,
 ' ' as third_party_ind,
 ' ' as remitter_name, 
 ' ' as beneficiary_name, 
 branch.branch_name, 
 ' ' as associate_name,
 fta.transaction_description,
 stat.status_desc,
 fta.transaction_key,
 acct.account_key,
 NULL as secondary_account_key,
 NULL as remitter_ext_party_key,
 NULL as beneficiary_ext_party_key,
 branch.branch_key,
 NULL as associate_key,
 pty.party_number as party_number,
 branch.branch_number,
 NULL as associate_number
FROM AMLCTR.fsk_account_event_alert evtalrt 
JOIN AMLCORE.fsc_account_dim acct on evtalrt.account_key = acct.account_key and evtalrt.segment_id = acct.segment_id
JOIN AMLCTR.fsk_transaction_alert fta ON evtalrt.transaction_key=fta.transaction_key and evtalrt.segment_id = fta.segment_id
JOIN AMLCORE.fsc_transaction_type_dim cred_typ ON cred_typ.transaction_type_key = evtalrt.transaction_type_key 
JOIN AMLCORE.fsc_party_account_bridge br on br.account_key = evtalrt.account_key and br.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_branch_dim branch on branch.branch_key = evtalrt.branch_key and branch.segment_id = evtalrt.segment_id
JOIN AMLCORE.fsc_transaction_status_dim stat on evtalrt.transaction_status_key = stat.transaction_status_key 
JOIN AMLCORE.fsc_party_dim pty on pty.party_key = br.party_key and pty.segment_id = br.segment_id
WHERE evtalrt.segment_id = 'BANK1KCTR'
;



